.. Xonotic Map Manager documentation master file, created by
   sphinx-quickstart on Tue Oct  4 20:14:48 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Xonotic Map Manager's documentation
===================================

A command-line package manager for the `xonotic-map-repository`_ project.

.. image:: _static/xmm.gif

.. image:: https://travis-ci.org/z/xonotic-map-manager.svg?branch=develop
    :target: https://travis-ci.org/z/xonotic-map-manager

**Features**

* Quickly install maps from the command-line

* Discovery and optional addition of your existing maps to XMM's library

* Repository-less install of map packages from a URL

* :ref:`Multi-server` support (track different maps per server)

* :ref:`Multi-repository`  support

* Plugin system

* Developer :ref:`API`, use xmm as a module

.. _repository: https://github.com/z/xonotic-map-repository
.. _xonotic-map-repository: https://www.github.com/z/xonotic-map-repository

**Get Started**

.. toctree::
   :maxdepth: 2

   intro
   installation
   configuration
   usage
   upgrading
   developers
   api
   tests
   license


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
